/*
Copyright (C) 2011 Craciun Dan <craciun.dan@tuxarena.com>

This file is part of NeonView.

NeonView is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

NeonView is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with NeonView.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "header.h"

void put_about (TM *tm) {
	GtkWidget *window;
	GtkWidget *vbox;
	GtkWidget *name;
	GtkWidget *auth;
	GtkWidget *site;

	GtkAccelGroup *accel_group;
	accel_group = gtk_accel_group_new();

	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_widget_set_size_request(window, 380, 180);
	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
	gtk_window_set_title(GTK_WINDOW(window), "About NeonView");
	gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
	gtk_container_set_border_width(GTK_CONTAINER(window), 10);

	gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);

	vbox = gtk_vbox_new(TRUE, 0);
	gtk_container_add(GTK_CONTAINER(window), vbox);

	char *markup;

	markup = g_markup_printf_escaped("<b>%s %s '%s'</b>", NAME, VERSION, CODENAME);
	name = gtk_label_new("");
	gtk_label_set_markup(GTK_LABEL(name), markup);

	GtkWidget *desc = gtk_label_new("A lightweight image viewer");

	markup = g_markup_printf_escaped("<a href=\"http://www.tuxarena.com/neonview/\">http://www.tuxarena.com/neonview/</a>");
	site = gtk_label_new("http://www.tuxarena.com/neonview/");
	gtk_label_set_markup(GTK_LABEL(site), markup);

	markup = g_markup_printf_escaped("Copyright (C) 2011 Craciun Dan");
	auth = gtk_label_new("");
	gtk_label_set_markup(GTK_LABEL(auth), markup);

	gtk_widget_modify_font(GTK_WIDGET(name), pango_font_description_from_string("DejaVu Sans 13"));
	gtk_widget_modify_font(GTK_WIDGET(desc), pango_font_description_from_string("DejaVu Sans 12"));
	gtk_widget_modify_font(GTK_WIDGET(auth), pango_font_description_from_string("DejaVu Sans 10"));
	gtk_widget_modify_font(GTK_WIDGET(site), pango_font_description_from_string("DejaVu Sans 12"));

	gtk_box_pack_start(GTK_BOX(vbox), name, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(vbox), desc, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(vbox), auth, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(vbox), site, FALSE, FALSE, 0);

	GtkWidget *ok;
	ok = gtk_button_new_with_mnemonic("_OK");
	gtk_widget_set_size_request(ok, 80, 30);
	gtk_box_pack_start(GTK_BOX(vbox), ok, FALSE, FALSE, 0);

	g_signal_connect_swapped(ok, "clicked", G_CALLBACK(gtk_widget_destroy), window);

	gtk_widget_add_accelerator(ok, "activate", accel_group, GDK_KEY_Escape, 0, GTK_ACCEL_VISIBLE);

	gtk_widget_show_all(vbox);
	gtk_widget_show(window);
}

void put_manual (TM *tm) {
	GtkWidget *window;
	GtkWidget *vbox;

	GtkWidget *textview;
	GtkTextBuffer *buffer;
	GtkTextIter iter;

	GtkWidget *scrolled;

	GtkAccelGroup *accel_group;
	accel_group = gtk_accel_group_new();

	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_widget_set_size_request(window, 640, 380);
	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
	gtk_container_set_border_width(GTK_CONTAINER(window), 0);
	gtk_window_set_title(GTK_WINDOW(window), "NeonView Manual");

	gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);

	vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), vbox);

	scrolled = gtk_scrolled_window_new(NULL, NULL);

	textview = gtk_text_view_new();
	gtk_text_view_set_left_margin(GTK_TEXT_VIEW(textview), 6);
	gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), FALSE);
	gtk_widget_set_size_request(textview, 620, 355);

	gtk_container_add(GTK_CONTAINER(scrolled), textview);
	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
	gtk_box_pack_start(GTK_BOX(vbox), scrolled, TRUE, TRUE, 0);

	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));

	gtk_text_buffer_create_tag(buffer, "bold", "weight", PANGO_WEIGHT_BOLD, NULL);
	gtk_text_buffer_create_tag(buffer, "wrap", "wrap-mode", GTK_WRAP_WORD, NULL);

	gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);

	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "\nIntroduction to NeonView\n", -1, "bold", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "NeonView is a minimalist, lightweight image viewer written in C and using the GTK toolkit.\n", -1, "wrap", NULL);

	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "\nFeatures\n", -1, "bold", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "- displays image formats supported by GTK, including JPG, PNG, SVG, GIF and TGA\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "- it saves the main window size between sessions\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "- displays next/prev image sorted by name\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "- normal size or fit to window view modes\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "- zoom in (shrink image) and zoom out (enlarge image)\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "- configuration window for several settings\n", -1, "wrap", NULL);

	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "\nKeyboard shortcuts\n", -1, "bold", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+O to open an image\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+N or Space to jump to the next image in directory\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+P or Backspace to jump to the previous image in directory\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+Q or Escape to quit\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+0 to view image at normal size\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+9 to fit image to window\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+- to zoom out (shrink image)\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "Ctrl+= to zoom in (enlarge image)\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "\nIn addition to these, you can press Escape in any window to close it (in the main window, the configuration window, the manual window and the about window).\n", -1, "wrap", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "\nConfiguration window\n", -1, "bold", NULL);
	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, "The configuration window is accessible via the Tools->Settings menu entry (or by pressing Ctrl+T).\n\n", -1, "wrap", NULL);

	GtkWidget *hbox;
	GtkWidget *ok;

	hbox = gtk_hbox_new(FALSE, 10);

	ok = gtk_button_new_with_mnemonic("_OK");
	gtk_widget_set_size_request(ok, 100, 32);
	g_signal_connect_swapped(ok, "clicked", G_CALLBACK(gtk_widget_destroy), window);

	gtk_box_pack_start(GTK_BOX(hbox), ok, TRUE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 10);

	gtk_widget_add_accelerator(ok, "activate", accel_group, GDK_KEY_Escape, 0, GTK_ACCEL_VISIBLE);

	gtk_widget_show_all(vbox);
	gtk_widget_show(window);
}

void put_homepage (TM *tm) {
	system("firefox http://www.tuxarena.com/neonview/ &");
}
